OC.L10N.register(
    "settings",
    {
    "Wrong current password" : "Mot de passe actuel incorrect",
    "The new password cannot be the same as the previous one" : "Le nouveau mot de passe ne peut pas être le même que l'ancien",
    "No user supplied" : "Aucun utilisateur fourni",
    "Authentication error" : "Erreur d'authentification",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues.",
    "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour avec succès.",
    "Unable to change password" : "Impossible de modifier le mot de passe",
    "%s password changed successfully" : "Le mot de passe %s a été correctement changé",
    "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer le courriel de réinitialisation. Veuillez contacter votre administrateur.",
    "installing and updating apps via the market or Federated Cloud Sharing" : "installation et mise à jour des applications via le marché ou le Cloud Fédéré Partagé",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilise %s %s, qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %s ne fonctionneront pas correctement.",
    "Invalid url '%s'. Urls should be set up like 'http://www.example.com' or 'https://www.example.com'" : "Url invalide '%s'. Les Urls doivent être de la forme 'http://www.exemple.com' ou 'https://www.exemple.com'",
    "Group already exists." : "Ce groupe existe déjà.",
    "Unable to add group." : "Impossible d'ajouter le groupe.",
    "Unable to delete group." : "Impossible de supprimer le groupe.",
    "Saved" : "Sauvegardé",
    "log-level out of allowed range" : "niveau de journalisation hors borne",
    "Invalid email address" : "Adresse mail invalide",
    "test email settings" : "Test des paramètres e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
    "Email sent" : "E-mail envoyé",
    "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
    "Couldn't change the email address because the user does not exist" : "Le courriel n'a pas pu être mise à jour car l'utilisateur n'existe pas",
    "Couldn't change the email address because the token is invalid" : "Le courriel n'a pas pu être mise à jour car le jeton est invalide",
    "Your %s account was created" : "Votre compte %s a été créé",
    "Invalid mail address" : "Adresse e-mail non valide",
    "A user with that name already exists." : "Un utilisateur avec ce nom existe déjà.",
    "Unable to create user." : "Impossible de créer l'utilisateur.",
    "The token provided is invalid." : "Le jeton fourni n'est pas valide.",
    "The token provided had expired." : "Le jeton fourni est expiré.",
    "Failed to create activation link. Please contact your administrator." : "Échec de la création du lien d'activation. Veuillez contacter votre administrateur.",
    "Can't send email to the user. Contact your administrator." : "Impossible d'envoyer un courrier électronique à l'utilisateur. Contactez votre administrateur.",
    "Failed to set password. Please contact the administrator." : "Impossible de définir le mot de passe. Veuillez contacter l'administrateur.",
    "Failed to set password. Please contact your administrator." : "Impossible de définir le mot de passe. Veuillez contacter votre administrateur.",
    "Failed to send email. Please contact your administrator." : "Impossible de définir le mot de passe. Veuillez contacter l'administrateur.",
    "Unable to delete user." : "Impossible de supprimer l'utilisateur.",
    "Forbidden" : "interdit",
    "Invalid user" : "Utilisateur non valable",
    "Unable to change mail address" : "Impossible de modifier l'adresse e-mail",
    "Email has been changed successfully." : "Le courriel a été correctement modifiée.",
    "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "Un mail a été envoyé à cette adresse pour confirmation. Jusqu'à ce que l'email soit vérifié, cette adresse ne sera pas configurée.",
    "No email was sent because you already sent one recently. Please try again later." : "Aucun courriel n'a été envoyé car vous en avez déjà reçu un récemment. Veuillez réessayer ultérieurement",
    "Your full name has been changed." : "Votre nom complet a été modifié.",
    "Unable to change full name" : "Impossible de changer le nom complet",
    "%s email address confirm" : "Confirmation de l'adresse de courriel %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Impossible d'envoyer le courriel de confirmation. Veuillez contacter votre administrateur.",
    "%s email address changed successfully" : "l'adresse de courriel %s a été modifiée avec succès",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Impossible d'envoyer un courriel de notification de changement d'adresse. Veuillez contacter votre administrateur.",
    "Unable to enable/disable user." : "Impossible d'activer/désactiver l'utilisateur.",
    "Create" : "Créer",
    "Change" : "Modification",
    "Delete" : "Supprimer",
    "Share" : "Partager",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "Langue changée",
    "Invalid request" : "Requête non valide",
    "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
    "Unknown user" : "Utilisateur inconnu",
    "Couldn't remove app." : "Impossible de supprimer l'application.",
    "Official" : "Officielle",
    "Approved" : "Approuvée",
    "All" : "Tous",
    "Enabled" : "Activées",
    "Not enabled" : "Désactivées",
    "No apps found for your version" : "Pas d'application trouvée pour votre version",
    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les applications officielles sont développées par et avec la communauté ownCloud. Elles permettent à ownCloud d'offrir ses fonctionnalités principales et sont prêtes pour une utilisation en environnement de production. ",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les tests de sécurité. Elles sont activement maintenues et leur code source est ouvert. Leurs développeurs les considèrent stables pour une utilisation normale.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
    "Please wait...." : "Veuillez patienter…",
    "Error while disabling app" : "Erreur lors de la désactivation de l'application",
    "Disable" : "Désactiver",
    "Enable" : "Activer",
    "Error while enabling app" : "Erreur lors de l'activation de l'application",
    "Error: this app cannot be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car elle rend le serveur instable",
    "Error: could not disable broken app" : "Erreur : Impossible de désactiver l’application cassé ",
    "Error while disabling broken app" : "Erreur lors de la désactivation de l'application cassé  .",
    "Updating...." : "Mise à jour...",
    "Error while updating app" : "Erreur lors de la mise à jour de l'application",
    "Updated" : "Mise à jour effectuée",
    "Uninstalling ...." : "Désinstallation...",
    "Error while uninstalling app" : "Erreur lors de la désinstallation de l'application",
    "Uninstall" : "Désinstaller",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
    "App update" : "Mise à jour",
    "Experimental" : "Expérimentale",
    "No apps found for {query}" : "Aucune application trouvée pour {query}",
    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
    "Migration started …" : "Migration démarrée...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
    "Valid until {date}" : "Valide jusqu'au {date}",
    "Disconnect" : "Déconnexion",
    "Error while loading browser sessions and device tokens" : "Erreur lors du chargement des jetons de la session du navigateur et de l'appareil",
    "Empty app name is not allowed." : "Un nom d'application vide n'est pas autorisé.",
    "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
    "Error while deleting the token" : "Erreur lors de la suppression du jeton",
    "Are you sure you want to remove this domain?" : "Êtes-vous sûr de vouloir supprimer ce domaine ?",
    "CORS" : "Partage de ressources d'origines croisées",
    "Sending..." : "Envoi en cours...",
    "Failed to change the email address." : "Impossible de modifier le courriel.",
    "Email changed successfully for {user}." : "L'Email de {utilisateur} à été mis à jour.",
    "An error occurred: {message}" : "Une erreur est survenue : {message}",
    "Select a profile picture" : "Selectionnez une photo de profil ",
    "Very weak password" : "Mot de passe de très faible sécurité",
    "Weak password" : "Mot de passe de faible sécurité",
    "So-so password" : "Mot de passe de sécurité tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe de forte sécurité",
    "Passwords do not match" : "Les mots de passe ne correspondent pas",
    "Groups" : "Groupes",
    "Unable to delete {objName}" : "Impossible de supprimer {objName}",
    "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
    "A valid group name must be provided" : "Vous devez spécifier un nom de groupe valide",
    "deleted {groupName}" : "{groupName} supprimé",
    "undo" : "annuler",
    "You are about to delete a group. This action can't be undone and is permanent. Are you sure that you want to permanently delete {groupName}?" : "Vous êtes sur le point de supprimer un groupe. Cette action ne peut pas être annulée et est permanente. Êtes-vous sûr de vouloir supprimer définitivement {groupName}? ",
    "Delete group" : "Effacer le groupe",
    "never" : "jamais",
    "deleted {userName}" : "{userName} supprimé",
    "You are about to delete a user. This action can't be undone and is permanent. All user data, files and shares will be deleted. Are you sure that you want to permanently delete {userName}?" : "Vous êtes sur le point de supprimer un utilisateur. Cette action ne peut pas être annulée et est permanente. Toutes les données utilisateur, fichiers et partages seront supprimés. Êtes-vous sûr de vouloir supprimer définitivement {userName}?",
    "Delete user" : "Supprimer l'utilisateur",
    "add group" : "ajouter un groupe",
    "Invalid quota value \"{val}\"" : "Valeur de quota invalide \"{val}\"",
    "enabled" : "activé",
    "disabled" : "désactivé",
    "User {uid} has been {state}!" : "L'utilisateur {uid} a été {state}!",
    "no group" : "Aucun groupe",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
    "Password successfully changed" : "Mot de passe changé avec succès",
    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
    "Error creating user: {message}" : "Erreur a la création d'un utilisateur : {message}",
    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
    "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
    "Use the following link to confirm your changes to the email address: {link}" : "Utilisez ce lien pour confirmer votre changement d'adresse de courriel : {link} ",
    "Email address changed to {mailAddress} successfully." : "L'adresse de courriel a été changée avec succès en :  {mailAddress}",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Please set the password by accessing it: <a href=\"%s\">Here</a><br><br>" : "Bonjour,<br><br>Votre compte %s a été créé.<br><br>Votre nom d'utilisateur : %s<br>Veuillez définir un mot de passe en <a href=\"%s\">cliquant ici.</a><br><br>",
    "Cheers!" : "À bientôt !",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : %s<br><br>\n",
    "Language" : "Langue",
    "Apps Management" : "Gestion des applications",
    "Developer documentation" : "Documentation pour développeurs",
    "by %s" : "par %s",
    "%s-licensed" : "Sous licence %s",
    "Documentation:" : "Documentation :",
    "User documentation" : "Documentation utilisateur",
    "Admin documentation" : "Documentation administrateur",
    "Visit website" : "Visiter le site web",
    "Report a bug" : "Signaler un bogue",
    "Show description …" : "Afficher la description...",
    "Hide description …" : "Masquer la description",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud minimale requise. Cela provoquera une erreur dans ownCloud 11+",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud maximale requise. Cela provoquera une erreur dans ownCloud 11+",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "Enable only for specific groups" : "Activer uniquement pour certains groupes",
    "Uninstall App" : "Désinstaller l'application",
    "Show enabled apps" : "Montrer les applications activées",
    "Show disabled apps" : "Montrer les applications désactivées",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Dernière tâche cron exécutée : %s.",
    "Last cron job execution: %s. Something seems wrong." : "Dernière tâche cron exécutée : %s. Quelque chose s'est mal passé.",
    "Cron was not executed yet!" : "Le cron n'a pas encore été exécuté !",
    "Open documentation" : "Voir la documentation",
    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Utilisez un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
    "SSL Root Certificates" : "Certificats Racines SSL",
    "Common Name" : "Nom d'usage",
    "Valid until" : "Valide jusqu'à",
    "Issued By" : "Délivré par",
    "Valid until %s" : "Valide jusqu'à %s",
    "Import root certificate" : "Importer un certificat racine",
    "Server-side encryption" : "Chiffrement côté serveur",
    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
    "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne peut garantir la sécurité du système. Veuillez consulter la documentation ownCloud pour comprendre comment fonctionne l'application de chiffrement, et les cas d'utilisation pris en charge.",
    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
    "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
    "Enable encryption" : "Activer le chiffrement",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
    "Start migration" : "Démarrer la migration",
    "Sharing" : "Partage",
    "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
    "Allow public uploads" : "Autoriser les téléversements publics",
    "Enforce password protection for read-only links" : "Forcer la protection par mot de passe pour les liens en lecture seule",
    "Enforce password protection for read + write links" : "Forcer la protection par mot de passe pour les liens en écriture et lecture",
    "Set default expiration date" : "Spécifier une date d'expiration par défaut",
    "Expire after " : "Expiration après ",
    "days" : "jours",
    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
    "Allow users to share file via social media" : "Autoriser les utilisateurs à partager un fichier via les réseaux sociaux",
    "Allow resharing" : "Autoriser le repartage",
    "Allow sharing with groups" : "Autoriser le partage avec les groupes",
    "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
    "Restrict users to only share with groups they are member of" : "N'autoriser les utilisateurs qu'à partager avec les groupes dont ils sont membre",
    "Allow users to send mail notification for shared files to other users" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
    "Exclude groups from sharing" : "Empêcher certains groupes de partager",
    "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée,  les noms complets doivent être indiqués.",
    "Restrict enumeration to group members" : "Restreindre l'énumération aux membres du groupe",
    "Default user and group share permissions" : "Autorisations par défaut de partage de groupe et d'utilisateur",
    "Extra field to display in autocomplete results" : "Champ supplémentaire à afficher dans les résultats de l'Auto-complétion",
    "None" : "Aucun",
    "User ID" : "ID utilisateur",
    "Email address" : "Adresse mail",
    "Imprint URL:" : "adresse d'Mentions légales : ",
    "Imprint URL" : "adresse d'Mentions légales",
    "Privacy Policy URL:" : "adresse de la Politique de confidentialité : ",
    "Privacy Policy URL" : "adresse de la Politique de confidentialité",
    "Save" : "Enregistrer",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
    "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
    "Warnings, errors and fatal issues" : "Avertissements, erreurs et erreurs fatales",
    "Errors and fatal issues" : "Erreurs et erreurs fatales",
    "Fatal issues only" : "Erreurs fatales uniquement",
    "Log" : "Log",
    "What to log" : "Ce qu'il faut journaliser",
    "Download logfile (%s)" : "Télécharger le fichier journal (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La taille du fichier journal excède 100 Mo. Le télécharger peut prendre un certain temps!",
    "Login" : "Login",
    "Plain" : "En clair",
    "NT LAN Manager" : "Gestionnaire du réseau NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Serveur e-mail",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Le fichier de configuration est en lecture seule. Veuillez ajuster votre configuration en éditant manuellement le fichier.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Dans une configuration de grappe, assurez-vous de synchroniser le fichier config.php sur chaque nœud.",
    "This is used for sending out notifications." : "Ceci est utilisé pour l'envoi des notifications.",
    "Send mode" : "Mode d'envoi",
    "Encryption" : "Chiffrement",
    "From address" : "Adresse source",
    "mail" : "e-mail",
    "Authentication method" : "Méthode d'authentification",
    "Authentication required" : "Authentification requise",
    "Server address" : "Adresse du serveur",
    "Port" : "Port",
    "Credentials" : "Informations d'identification",
    "SMTP Username" : "Nom d'utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Store credentials" : "Enregistrer les identifiants",
    "Test email settings" : "Tester les paramètres e-mail",
    "Send email" : "Envoyer un e-mail",
    "Security & setup warnings" : "Avertissements de sécurité & configuration",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture avant chaque mise à jour.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Votre base de données n'est pas lancée avec le niveau d'isolation de transaction \"READ COMMITED\". Cela peut causer des problèmes lorsque plusieurs actions sont lancées parallèlement.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous recommandons de mettre %1$s à jour.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers devrait être configuré pour utiliser le verrouillage basé sur la mémoire, et non le verrouillage lent, par défaut, basée sur la base de données. Consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
    "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux n'ont pu être configurés avec prise en charge d'UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilisation de SQLite est particulièrement déconseillée si vous utilisez le client de bureau pour synchroniser vos données.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Nous recommandons d'activer la tâche planifiée système qui, comme toute autre tâche planifiée, a des implications possibles sur  les performances et la fiabilité.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
    "All checks passed." : "Tous les tests ont réussi.",
    "System Status" : "Statut du système",
    "Tips & tricks" : "Trucs et astuces",
    "How to do backups" : "Comment faire des sauvegardes",
    "Performance tuning" : "Ajustement des performances",
    "Improving the config.php" : "Amélioration du config.php ",
    "Theming" : "Personnalisation de l'apparence",
    "Hardening and security guidance" : "Guide pour le renforcement et la sécurité",
    "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
    "Desktop client" : "Client de bureau",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vous souhaitez soutenir le projet\n⇥⇥⇥<a href=\"https://owncloud.org/contribute\"\n\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">rejoignez l'équipe de développement</a>\n\n⇥⇥⇥ou\n\n⇥⇥⇥<a href=\"https://owncloud.org/promote\"\n\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">Faites passer !</a>!",
    "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
    "White-listed Domains" : "Liste blanche de domaines",
    "No Domains." : "Pas de domaines.",
    "Domain" : "Domaine",
    "Add Domain" : "Ajouter un domaine",
    "Add" : "Ajouter",
    "Profile picture" : "Photo de profil",
    "Upload new" : "Nouvelle depuis votre ordinateur",
    "Select from Files" : "Sélectionner depuis les Fichiers",
    "Remove image" : "Supprimer l'image",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
    "Picture provided by original account" : "Photo fournie par le compte original",
    "Cancel" : "Annuler",
    "Choose as profile picture" : "Définir comme image de profil",
    "Full name" : "Nom complet",
    "No display name set" : "Aucun nom d'affichage configuré",
    "Email" : "Adresse e-mail",
    "Your email address" : "Votre adresse e-mail",
    "Change email" : "Changer l'adresse de courriel",
    "Set email" : "Définir le courriel",
    "For password recovery and notifications" : "Pour la récupération de mot de passe et les notifications",
    "No email address set" : "Aucune adresse e-mail configurée",
    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
    "You are not a member of any groups." : "Vous n'êtes membre d'aucun groupe.",
    "Password" : "Mot de passe",
    "Unable to change your password" : "Impossible de changer votre mot de passe",
    "Current password" : "Mot de passe actuel",
    "New password" : "Nouveau mot de passe",
    "Change password" : "Changer de mot de passe",
    "Help translate" : "Aidez à traduire",
    "You are using %s" : "Vous utilisez %s",
    "You are using %s of %s (%s %%)" : "Vous utilisez %s sur %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Développé par la {communityopen}communauté ownCloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sessions",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Voivi les clients Web, de bureau et mobiles actuellement connectés à votre %s.",
    "Browser" : "Navigateur",
    "Most recent activity" : "Activité la plus récente",
    "App passwords / tokens" : "mots de passe / jetons d'application",
    "You've linked these apps." : "Vous avez lié ces applications.",
    "Name" : "Nom",
    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Les mots de passe d'application ou jetons sont des code d'accés qui donne à une application ou à un appareil les droits d'accès à votre compte %s.",
    "App name" : "Nom de l'application",
    "Create new app passcode" : "Créer un nouveau code de sécurité d'application",
    "Use the credentials below to configure your app or device." : "Utilisez les identifiants ci-dessous pour configurer votre application ou votre périphérique.",
    "Username" : "Nom d'utilisateur",
    "Password / Token" : "mot de passe / jeton",
    "Done" : "Terminé",
    "Version" : "Version",
    "The activation link has expired. Click the button below to request a new one and complete the registration." : "Le lien d'activation a expiré. Cliquez sur le bouton ci-dessous pour en demander un nouveau et terminer l'enregistrement.",
    "Resend activation link" : "Renvoyer le lien d'activation",
    "New Password" : "Nouveau mot de passe",
    "Confirm Password" : "Confirmer le mot de passe",
    "Please set your password" : "Veuillez entrer votre mot de passe",
    "Personal" : "Personnel",
    "Admin" : "Administration",
    "Currently no settings are available in this category" : "Actuellement, aucun paramètre n'est disponible dans cette catégorie",
    "The administrators can enable additional apps which add settings sections here." : "Les administrateurs peuvent activer des applications supplémentaires qui ajoutent des rubriques de paramètres ici.",
    "Activation link was sent to an email address, if one was configured." : "Le lien d'activation a été envoyé à une adresse électronique, si elle a été configurée.",
    "Settings" : "Paramètres",
    "Show enabled/disabled option" : "Afficher l'option Activé/Désactivé",
    "Show storage location" : "Afficher l'emplacement du stockage",
    "Show last log in" : "Montrer la dernière connexion",
    "Show user backend" : "Montrer la source de l'identifiant",
    "Set password for new users" : "Définir un mot de passe pour les nouveaux utilisateurs",
    "Show email address" : "Afficher l'adresse e-mail",
    "Show password field" : "Montrer le champs mot de passe",
    "Show quota field" : "Montrer le champs quota",
    "E-Mail" : "Courriel",
    "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
    "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
    "Add Group" : "Ajouter un groupe",
    "Group" : "Groupe",
    "Everyone" : "Tout le monde",
    "Admins" : "Administrateurs",
    "Default Quota" : "Quota par défaut",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
    "Unlimited" : "Illimité",
    "Other" : "Autre",
    "Full Name" : "Nom complet",
    "Group Admin for" : "Administrateur de groupe pour",
    "Quota" : "Quota",
    "Storage Location" : "Emplacement du Stockage",
    "User Backend" : "Source",
    "Last Login" : "Dernière Connexion",
    "change full name" : "Modifier le nom complet",
    "set new password" : "Changer le mot de passe",
    "change email address" : "changer l'adresse e-mail",
    "Default" : "Défaut"
},
"nplurals=2; plural=(n > 1);");
